# coding: utf-8
"""
Модуль моделей приложения.
"""
__author__ = 'fattakhov'

import datetime

from django.db import models
from django.utils import simplejson as json
from django.db.models.signals import post_save
from django.dispatch import receiver

from djcelery.models import PeriodicTask, CrontabSchedule
from m3.actions import ApplicationLogicException

from kinder.core.models import BaseReplicatedModel
from kinder.core.unit.models import UnitKind
from kinder.core.unit.models import Unit
from constants import (AGE_CATEGORIES_FULL, AGE_CATEGORIES_FULL_CURRENT,
                       APPLICATION_STATUSES, DELIVERY_TYPES,
                       BENEFIT_TYPES, HEALTH_NEEDS, DOO_TYPES,
                       GROUP_TYPES, AGE_CATEGORIES_CUT, NO, AGE_CATEGORIES_FULL_MAP)
import settings as gs_settings

@receiver(post_save, sender=Unit)
def create_favorites(sender, instance, created, **kwargs):
    if created:
        GisdoUnit.objects.create(unit=instance)

class GisdoUnit(BaseReplicatedModel):
    """
    Модель, для расширения учреждений
    """
    unit = models.OneToOneField(Unit, parent_link=True, related_name='gisdo')
    not_on_federal_report = models.BooleanField(default=False)

    # идентификатор ДОО
    @property
    def doo_identity(self):
        """
        композитный идентификатор ДОО, заполняется следующим образом:
        xxyyyyyyyyyyyyzzzz,
        xx - код региона (2 знака) из настроек проекта
        yyyyyyyyyyyy - цифры кода ОКТМО (11 знаков)
        zzzz - номер ДОО (поле doo_number)
        """
        octmo_max_length = 11
        doo_number_max_length = 4
        region_max_length = 2

        if self.unit.kind.id != UnitKind.DOU:
            raise ApplicationLogicException(
                u'свойство doo_identity есть только у ДОУ')
        if not gs_settings.REGION_CODE:
            raise ApplicationLogicException(u'Не задан код региона')
        if len(str(gs_settings.REGION_CODE)) > region_max_length:
            raise ApplicationLogicException(
                u'Длина кода региона превышает максимальное значение')

        identity = str(gs_settings.REGION_CODE).rjust(region_max_length, '0')

        octmo = self.unit.get_mo().octmo
        if octmo:
            identity += self.unit.get_mo().octmo.rjust(octmo_max_length, '0')
        else:
            raise ApplicationLogicException(
                u'В МО %s не задан код ОКТМО' % self.unit.get_mo().display())

        identity += str(self.unit.doo_number).rjust(doo_number_max_length, '0')
        return identity

class ReportForm(BaseReplicatedModel):
    """
    Форма отчетности "Федеральная отчетность"
    """
    date = models.DateTimeField(verbose_name=u'Дата создания', auto_now_add=True)
    sent_time = models.DateTimeField(verbose_name=u'Время отправки', null=True)
    user = models.ForeignKey('users.UserProfile', verbose_name=u'Пользователь', null=True)
    unit = models.ForeignKey('unit.Unit', verbose_name=u'Учреждение', null=True)
    xml = models.TextField(verbose_name=u'Сформированная XML', null=True)
    in_progress = models.BooleanField(default=False, verbose_name=u'Сбор отчета')

    class Meta:
        verbose_name = u"Форма 'Федеральная отчетность'"
        verbose_name_plural = u"Формы 'Федеральная отчетность'"

    def __unicode__(self):
        return u"%s от %s" % (self._meta.verbose_name, self.date)

    @property
    def progress(self):
        return u'В процессе сборки' if self.in_progress else u'Собран'

    @property
    def sent(self):
        return u'Отправлен' if self.sent_time else u'Не отправлен'


class ReportFormRow(BaseReplicatedModel):
    """
    Строка отчета для конкретного учреждения
    """
    report = models.ForeignKey(ReportForm, verbose_name=u'Форма отчетности')
    unit = models.ForeignKey('unit.Unit', verbose_name=u'Учреждение')

    applications = models.TextField(verbose_name=u'Информация по заявлениям', null=True)
    queues = models.TextField(verbose_name=u'Информация по очередям', null=True)
    enrolled = models.TextField(verbose_name=u'Информация о зачисленных детях', null=True)
    capacities = models.TextField(verbose_name=u'Информация о свободных местах', null=True)

    class Meta:
        verbose_name = u"Показатель по учреждению"
        verbose_name_plural = u"Показатели по учреждению"

    def __unicode__(self):
        return u"%s %s на %s" % (self._meta.verbose_name,
                                 self.unit.display(),
                                 self.report.date if self.report else '-')

    def get_applications_view_data(self):
        """
        Данные отчета по учреждению по заявлениям в формате,
        годном для загрузки в грид
        """
        ap = json.loads(self.applications)
        common = u'Общее количество поданных заявлений на постановку в очередь детей %s'
        delivery = u'Общее количество заявлений поданных %s'
        non_state = (u'Общее количество поданных заявлений на постановку в очередь в '
                     u'негосударственные ДОО детей в возрасте %s')
        business = (u'Общее количество поданных заявлений на постановку в очередь у ИП, '
                    u'реализующих программы дошкольного образования, детей в возрасте %s')
        short_stay = (u'Общее количество поданных заявлений на постановку в очередь в '
                      u'группы кратковременного пребывания детей в возрасте %s')

        data = [
            (0, common % AGE_CATEGORIES_FULL['2-6-MONTHS'], ap['COMMON'][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (1, common % AGE_CATEGORIES_FULL['0.5-1-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (2, common % AGE_CATEGORIES_FULL['1-1.5-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (3, common % AGE_CATEGORIES_FULL['1.5-2-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (4, common % AGE_CATEGORIES_FULL['2-2.5-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (5, common % AGE_CATEGORIES_FULL['2.5-3-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (6, common % AGE_CATEGORIES_FULL['3-3.5-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (7, common % AGE_CATEGORIES_FULL['3.5-4-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (8, common % AGE_CATEGORIES_FULL['4-4.5-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (9, common % AGE_CATEGORIES_FULL['4.5-5-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (10, common % AGE_CATEGORIES_FULL['5-5.5-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (11, common % AGE_CATEGORIES_FULL['5.5-6-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (12, common % AGE_CATEGORIES_FULL['6-6.5-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (13, common % AGE_CATEGORIES_FULL['6.5-7-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (14, common % AGE_CATEGORIES_FULL['7-7.5-YEARS'], ap['COMMON'][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),

            (15, delivery % DELIVERY_TYPES['PORTAL'], ap['DELIVERY'][DELIVERY_TYPES['PORTAL']]),
            (16, delivery % DELIVERY_TYPES['IN_PERSON'], ap['DELIVERY'][DELIVERY_TYPES['IN_PERSON']]),

            (17, non_state % AGE_CATEGORIES_FULL['2-6-MONTHS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (18, non_state % AGE_CATEGORIES_FULL['0.5-1-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (19, non_state % AGE_CATEGORIES_FULL['1-1.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (20, non_state % AGE_CATEGORIES_FULL['1.5-2-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (21, non_state % AGE_CATEGORIES_FULL['2-2.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (22, non_state % AGE_CATEGORIES_FULL['2.5-3-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (23, non_state % AGE_CATEGORIES_FULL['3-3.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (24, non_state % AGE_CATEGORIES_FULL['3.5-4-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (25, non_state % AGE_CATEGORIES_FULL['4-4.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (26, non_state % AGE_CATEGORIES_FULL['4.5-5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (27, non_state % AGE_CATEGORIES_FULL['5-5.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (28, non_state % AGE_CATEGORIES_FULL['5.5-6-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (29, non_state % AGE_CATEGORIES_FULL['6-6.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (30, non_state % AGE_CATEGORIES_FULL['6.5-7-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (31, non_state % AGE_CATEGORIES_FULL['7-7.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),

            (32, business % AGE_CATEGORIES_FULL['2-6-MONTHS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (33, business % AGE_CATEGORIES_FULL['0.5-1-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (34, business % AGE_CATEGORIES_FULL['1-1.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (35, business % AGE_CATEGORIES_FULL['1.5-2-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (36, business % AGE_CATEGORIES_FULL['2-2.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (37, business % AGE_CATEGORIES_FULL['2.5-3-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (38, business % AGE_CATEGORIES_FULL['3-3.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (39, business % AGE_CATEGORIES_FULL['3.5-4-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (40, business % AGE_CATEGORIES_FULL['4-4.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (41, business % AGE_CATEGORIES_FULL['4.5-5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (42, business % AGE_CATEGORIES_FULL['5-5.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (43, business % AGE_CATEGORIES_FULL['5.5-6-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (44, business % AGE_CATEGORIES_FULL['6-6.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (45, business % AGE_CATEGORIES_FULL['6.5-7-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (46, business % AGE_CATEGORIES_FULL['7-7.5-YEARS'], ap['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),

            (47, short_stay % AGE_CATEGORIES_CUT['2M-3YEARS'], ap['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (48, short_stay % AGE_CATEGORIES_CUT['3-5-YEARS'], ap['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (49, short_stay % AGE_CATEGORIES_CUT['5-7.5-YEARS'], ap['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),

            (50, u'Количество отказов', ap['STATUS'][APPLICATION_STATUSES['DENIED']]),
        ]
        return data

    def get_queues_view_data(self):
        """
        Данные отчета по учреждению по очередям в формате,
        годном для загрузки в грид
        """
        qu = json.loads(self.queues)
        common = u'Количество детей в очереди (отложенный спрос) в возрасте %s'
        want_change_doo = u'Количество детей в очереди (с учетом детей, желающих сменить ДОО) в возрасте %s'
        benefits = u'Количество детей в очереди, имеющих право на льготное зачисление в возрасте %s'
        benefit_type = u'Количество детей в очереди, имеющих право на льготное зачисление на основании %s льгот'
        disabled = u'Количество детей в очереди с ограниченными возможностями здоровья в возрасте %s'
        needs_by_group = u'Количество детей в очереди, нуждающихся в %s группах'
        non_state = u'Количество детей в очереди в негосударственные ДОО в возрасте %s'
        business = u'Количество детей в очереди у ИП, реализующих программы дошкольного образования, в возрасте %s'

        short_stay = u'Количество детей в очереди в группы кратковременного пребывания в возрасте %s'
        actual = u'Количество детей в очереди, необеспеченных местом в ДОО в возрасте %s (актуальный спрос)'

        unsecured = u'Количество детей в очереди необеспеченных местом в ДОО в возрасте %s (актуальный спрос на текущую дату)'
        registered = u'Количество детей в очереди (отложенный спрос) в возрасте %s (на текущую дату)'

        data = [
            (0, common % AGE_CATEGORIES_FULL['2-6-MONTHS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (1, common % AGE_CATEGORIES_FULL['0.5-1-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (2, common % AGE_CATEGORIES_FULL['1-1.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (3, common % AGE_CATEGORIES_FULL['1.5-2-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (4, common % AGE_CATEGORIES_FULL['2-2.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (5, common % AGE_CATEGORIES_FULL['2.5-3-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (6, common % AGE_CATEGORIES_FULL['3-3.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (7, common % AGE_CATEGORIES_FULL['3.5-4-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (8, common % AGE_CATEGORIES_FULL['4-4.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (9, common % AGE_CATEGORIES_FULL['4.5-5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (10, common % AGE_CATEGORIES_FULL['5-5.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (11, common % AGE_CATEGORIES_FULL['5.5-6-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (12, common % AGE_CATEGORIES_FULL['6-6.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (13, common % AGE_CATEGORIES_FULL['6.5-7-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (14, common % AGE_CATEGORIES_FULL['7-7.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),

            (15, want_change_doo % AGE_CATEGORIES_FULL['2-6-MONTHS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (16, want_change_doo % AGE_CATEGORIES_FULL['0.5-1-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (17, want_change_doo % AGE_CATEGORIES_FULL['1-1.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (18, want_change_doo % AGE_CATEGORIES_FULL['1.5-2-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (19, want_change_doo % AGE_CATEGORIES_FULL['2-2.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (20, want_change_doo % AGE_CATEGORIES_FULL['2.5-3-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (21, want_change_doo % AGE_CATEGORIES_FULL['3-3.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (22, want_change_doo % AGE_CATEGORIES_FULL['3.5-4-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (23, want_change_doo % AGE_CATEGORIES_FULL['4-4.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (24, want_change_doo % AGE_CATEGORIES_FULL['4.5-5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (25, want_change_doo % AGE_CATEGORIES_FULL['5-5.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (26, want_change_doo % AGE_CATEGORIES_FULL['5.5-6-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (27, want_change_doo % AGE_CATEGORIES_FULL['6-6.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (28, want_change_doo % AGE_CATEGORIES_FULL['6.5-7-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (29, want_change_doo % AGE_CATEGORIES_FULL['7-7.5-YEARS'], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_WANT_CHANGE_DOO']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),

            (30, benefits % AGE_CATEGORIES_FULL['2-6-MONTHS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (31, benefits % AGE_CATEGORIES_FULL['0.5-1-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (32, benefits % AGE_CATEGORIES_FULL['1-1.5-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (33, benefits % AGE_CATEGORIES_FULL['1.5-2-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (34, benefits % AGE_CATEGORIES_FULL['2-2.5-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (35, benefits % AGE_CATEGORIES_FULL['2.5-3-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (36, benefits % AGE_CATEGORIES_FULL['3-3.5-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (37, benefits % AGE_CATEGORIES_FULL['3.5-4-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (38, benefits % AGE_CATEGORIES_FULL['4-4.5-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (39, benefits % AGE_CATEGORIES_FULL['4.5-5-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (40, benefits % AGE_CATEGORIES_FULL['5-5.5-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (41, benefits % AGE_CATEGORIES_FULL['5.5-6-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (42, benefits % AGE_CATEGORIES_FULL['6-6.5-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (43, benefits % AGE_CATEGORIES_FULL['6.5-7-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (44, benefits % AGE_CATEGORIES_FULL['7-7.5-YEARS'], qu['BENEFITS'][BENEFIT_TYPES['HAVE_BENEFITS']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),

            (45, benefit_type % u'федеральных', qu['BENEFITS'][BENEFIT_TYPES['FEDERAL']]),
            (46, benefit_type % u'региональных', qu['BENEFITS'][BENEFIT_TYPES['REGIONAL']]),

            (47, disabled % AGE_CATEGORIES_FULL['2-6-MONTHS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (48, disabled % AGE_CATEGORIES_FULL['0.5-1-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (49, disabled % AGE_CATEGORIES_FULL['1-1.5-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (50, disabled % AGE_CATEGORIES_FULL['1.5-2-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (51, disabled % AGE_CATEGORIES_FULL['2-2.5-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (52, disabled % AGE_CATEGORIES_FULL['2.5-3-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (53, disabled % AGE_CATEGORIES_FULL['3-3.5-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (54, disabled % AGE_CATEGORIES_FULL['3.5-4-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (55, disabled % AGE_CATEGORIES_FULL['4-4.5-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (56, disabled % AGE_CATEGORIES_FULL['4.5-5-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (57, disabled % AGE_CATEGORIES_FULL['5-5.5-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (58, disabled % AGE_CATEGORIES_FULL['5.5-6-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (59, disabled % AGE_CATEGORIES_FULL['6-6.5-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (60, disabled % AGE_CATEGORIES_FULL['6.5-7-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (61, disabled % AGE_CATEGORIES_FULL['7-7.5-YEARS'], qu['HEALTH_NEEDS'][HEALTH_NEEDS['DISABLED']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),

            (62, needs_by_group % u'компенсирующих', qu['HEALTH_NEEDS'][HEALTH_NEEDS['CORRECT']]),
            (63, needs_by_group % u'оздоровительных', qu['HEALTH_NEEDS'][HEALTH_NEEDS['HEALTH']]),

            (64, non_state % AGE_CATEGORIES_FULL['2-6-MONTHS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (65, non_state % AGE_CATEGORIES_FULL['0.5-1-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (66, non_state % AGE_CATEGORIES_FULL['1-1.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (67, non_state % AGE_CATEGORIES_FULL['1.5-2-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (68, non_state % AGE_CATEGORIES_FULL['2-2.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (69, non_state % AGE_CATEGORIES_FULL['2.5-3-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (70, non_state % AGE_CATEGORIES_FULL['3-3.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (71, non_state % AGE_CATEGORIES_FULL['3.5-4-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (72, non_state % AGE_CATEGORIES_FULL['4-4.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (73, non_state % AGE_CATEGORIES_FULL['4.5-5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (74, non_state % AGE_CATEGORIES_FULL['5-5.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (75, non_state % AGE_CATEGORIES_FULL['5.5-6-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (76, non_state % AGE_CATEGORIES_FULL['6-6.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (77, non_state % AGE_CATEGORIES_FULL['6.5-7-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (78, non_state % AGE_CATEGORIES_FULL['7-7.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),

            (79, business % AGE_CATEGORIES_FULL['2-6-MONTHS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (80, business % AGE_CATEGORIES_FULL['0.5-1-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (81, business % AGE_CATEGORIES_FULL['1-1.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (82, business % AGE_CATEGORIES_FULL['1.5-2-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (83, business % AGE_CATEGORIES_FULL['2-2.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (84, business % AGE_CATEGORIES_FULL['2.5-3-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (85, business % AGE_CATEGORIES_FULL['3-3.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (86, business % AGE_CATEGORIES_FULL['3.5-4-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (87, business % AGE_CATEGORIES_FULL['4-4.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (88, business % AGE_CATEGORIES_FULL['4.5-5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (89, business % AGE_CATEGORIES_FULL['5-5.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (90, business % AGE_CATEGORIES_FULL['5.5-6-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (91, business % AGE_CATEGORIES_FULL['6-6.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (92, business % AGE_CATEGORIES_FULL['6.5-7-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (93, business % AGE_CATEGORIES_FULL['7-7.5-YEARS'], qu['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),

            (94, short_stay % AGE_CATEGORIES_CUT['2M-3YEARS'], qu['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (95, short_stay % AGE_CATEGORIES_CUT['3-5-YEARS'], qu['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (96, short_stay % AGE_CATEGORIES_CUT['5-7.5-YEARS'], qu['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),

            (97, actual % AGE_CATEGORIES_FULL['2-6-MONTHS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (98, actual % AGE_CATEGORIES_FULL['0.5-1-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (99, actual % AGE_CATEGORIES_FULL['1-1.5-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (100, actual % AGE_CATEGORIES_FULL['1.5-2-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (101, actual % AGE_CATEGORIES_FULL['2-2.5-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (102, actual % AGE_CATEGORIES_FULL['2.5-3-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (103, actual % AGE_CATEGORIES_FULL['3-3.5-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (104, actual % AGE_CATEGORIES_FULL['3.5-4-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (105, actual % AGE_CATEGORIES_FULL['4-4.5-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (106, actual % AGE_CATEGORIES_FULL['4.5-5-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (107, actual % AGE_CATEGORIES_FULL['5-5.5-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (108, actual % AGE_CATEGORIES_FULL['5.5-6-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (109, actual % AGE_CATEGORIES_FULL['6-6.5-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (110, actual % AGE_CATEGORIES_FULL['6.5-7-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (111, actual % AGE_CATEGORIES_FULL['7-7.5-YEARS'], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),
        ]
        # В старых отчетах этот показатель не вычислялся
        if (AGE_CATEGORIES_FULL_CURRENT['C2-6-MONTHS'] in qu['DOO_TYPE'][NO] and
            AGE_CATEGORIES_FULL_CURRENT['C2-6-MONTHS'] in qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']]):
            data.extend([
                (112, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C2-6-MONTHS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C2-6-MONTHS']]),
                (113, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C0.5-1-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C0.5-1-YEARS']]),
                (114, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C1-1.5-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C1-1.5-YEARS']]),
                (115, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C1.5-2-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C1.5-2-YEARS']]),
                (116, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C2-2.5-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C2-2.5-YEARS']]),
                (117, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C2.5-3-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C2.5-3-YEARS']]),
                (118, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C3-3.5-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C3-3.5-YEARS']]),
                (119, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C3.5-4-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C3.5-4-YEARS']]),
                (120, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C4-4.5-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C4-4.5-YEARS']]),
                (121, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C4.5-5-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C4.5-5-YEARS']]),
                (122, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C5-5.5-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C5-5.5-YEARS']]),
                (123, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C5.5-6-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C5.5-6-YEARS']]),
                (124, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C6-6.5-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C6-6.5-YEARS']]),
                (125, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C6.5-7-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C6.5-7-YEARS']]),
                (126, unsecured % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C7-7.5-YEARS']], qu['DOO_TYPE'][NO][AGE_CATEGORIES_FULL_CURRENT['C7-7.5-YEARS']]),
                (127, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C2-6-MONTHS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C2-6-MONTHS']]),
                (128, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C0.5-1-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C0.5-1-YEARS']]),
                (129, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C1-1.5-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C1-1.5-YEARS']]),
                (130, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C1.5-2-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C1.5-2-YEARS']]),
                (131, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C2-2.5-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C2-2.5-YEARS']]),
                (132, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C2.5-3-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C2.5-3-YEARS']]),
                (133, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C3-3.5-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C3-3.5-YEARS']]),
                (134, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C3.5-4-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C3.5-4-YEARS']]),
                (135, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C4-4.5-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C4-4.5-YEARS']]),
                (136, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C4.5-5-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C4.5-5-YEARS']]),
                (137, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C5-5.5-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C5-5.5-YEARS']]),
                (138, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C5.5-6-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C5.5-6-YEARS']]),
                (139, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C6-6.5-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C6-6.5-YEARS']]),
                (140, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C6.5-7-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C6.5-7-YEARS']]),
                (141, registered % AGE_CATEGORIES_FULL_MAP[AGE_CATEGORIES_FULL_CURRENT['C7-7.5-YEARS']], qu['STATUS'][APPLICATION_STATUSES['IN_LINE_DEFERRED']][AGE_CATEGORIES_FULL_CURRENT['C7-7.5-YEARS']]),
            ])

        return data

    def get_enrolled_view_data(self):
        """
        Данные отчета по учреждению по зачисленным детям в формате,
        годном для загрузки в грид
        """
        en = json.loads(self.enrolled)
        common = u'Количество зачисленных детей в возрасте %s'
        disabled = (u'Количество детей, зачисленных в группы для детей с '
                    u'ограниченными возможностями здоровья в возрасте %s')
        non_state = u'Количество детей, зачисленных  в негосударственные ДОО, в возрасте %s'
        business = u'Количество детей, зачисленных у ИП, реализующих программы дошкольного образования, в возрасте %s'
        short_stay = u'Количество детей, зачисленных в группы кратковременного пребывания, в возрасте %s'
        care_non_state = (u'Количество детей, зачисленных в группы по присмотру и уходу в '
                          u'негосударственных ДОО, для детей в возрасте %s')
        care_business = (u'Количество детей, зачисленных в группы по присмотру и уходу в ИП, реализующих '
                         u'программы дошкольного образования,  в возрасте  %s')
        inline_enrolled = u'Количество детей в возрасте %s'
        all_childs = u'Общее количество детей в возрасте %s'

        count_people_current_date = u'Численность детей, посещающих дошкольную образовательную организацию (%s)'

        data = [
            (0, common % AGE_CATEGORIES_FULL['2-6-MONTHS'], en['COMMON'][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (1, common % AGE_CATEGORIES_FULL['0.5-1-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (2, common % AGE_CATEGORIES_FULL['1-1.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (3, common % AGE_CATEGORIES_FULL['1.5-2-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (4, common % AGE_CATEGORIES_FULL['2-2.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (5, common % AGE_CATEGORIES_FULL['2.5-3-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (6, common % AGE_CATEGORIES_FULL['3-3.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (7, common % AGE_CATEGORIES_FULL['3.5-4-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (8, common % AGE_CATEGORIES_FULL['4-4.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (9, common % AGE_CATEGORIES_FULL['4.5-5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (10, common % AGE_CATEGORIES_FULL['5-5.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (11, common % AGE_CATEGORIES_FULL['5.5-6-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (12, common % AGE_CATEGORIES_FULL['6-6.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (13, common % AGE_CATEGORIES_FULL['6.5-7-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (14, common % AGE_CATEGORIES_FULL['7-7.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),
            (15, u'Количество детей, желающих сменить ДОО', en['STATUS'][APPLICATION_STATUSES['WANT_CHANGE_DOO']]),
            (16, u'Количество детей, зачисленных в семейные дошкольные группы', en['GROUP_TYPE'][GROUP_TYPES['FAMILY']]),
            (17, disabled % AGE_CATEGORIES_FULL['2-6-MONTHS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (18, disabled % AGE_CATEGORIES_FULL['0.5-1-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (19, disabled % AGE_CATEGORIES_FULL['1-1.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (20, disabled % AGE_CATEGORIES_FULL['1.5-2-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (21, disabled % AGE_CATEGORIES_FULL['2-2.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (22, disabled % AGE_CATEGORIES_FULL['2.5-3-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (23, disabled % AGE_CATEGORIES_FULL['3-3.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (24, disabled % AGE_CATEGORIES_FULL['3.5-4-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (25, disabled % AGE_CATEGORIES_FULL['4-4.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (26, disabled % AGE_CATEGORIES_FULL['4.5-5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (27, disabled % AGE_CATEGORIES_FULL['5-5.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (28, disabled % AGE_CATEGORIES_FULL['5.5-6-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (29, disabled % AGE_CATEGORIES_FULL['6-6.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (30, disabled % AGE_CATEGORIES_FULL['6.5-7-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (31, disabled % AGE_CATEGORIES_FULL['7-7.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),
            (32, u'Количество детей, зачисленных в компенсирующих группах', en['GROUP_TYPE'][GROUP_TYPES['CORRECT']]),
            (33, u'Количество детей, зачисленных в оздоровительных группах', en['GROUP_TYPE'][GROUP_TYPES['HEALTH']]),
            (34, non_state % AGE_CATEGORIES_FULL['2-6-MONTHS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (35, non_state % AGE_CATEGORIES_FULL['0.5-1-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (36, non_state % AGE_CATEGORIES_FULL['1-1.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (37, non_state % AGE_CATEGORIES_FULL['1.5-2-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (38, non_state % AGE_CATEGORIES_FULL['2-2.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (39, non_state % AGE_CATEGORIES_FULL['2.5-3-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (40, non_state % AGE_CATEGORIES_FULL['3-3.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (41, non_state % AGE_CATEGORIES_FULL['3.5-4-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (42, non_state % AGE_CATEGORIES_FULL['4-4.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (43, non_state % AGE_CATEGORIES_FULL['4.5-5-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (44, non_state % AGE_CATEGORIES_FULL['5-5.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (45, non_state % AGE_CATEGORIES_FULL['5.5-6-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (46, non_state % AGE_CATEGORIES_FULL['6-6.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (47, non_state % AGE_CATEGORIES_FULL['6.5-7-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (48, non_state % AGE_CATEGORIES_FULL['7-7.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),
            (49, business % AGE_CATEGORIES_FULL['2-6-MONTHS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (50, business % AGE_CATEGORIES_FULL['0.5-1-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (51, business % AGE_CATEGORIES_FULL['1-1.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (52, business % AGE_CATEGORIES_FULL['1.5-2-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (53, business % AGE_CATEGORIES_FULL['2-2.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (54, business % AGE_CATEGORIES_FULL['2.5-3-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (55, business % AGE_CATEGORIES_FULL['3-3.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (56, business % AGE_CATEGORIES_FULL['3.5-4-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (57, business % AGE_CATEGORIES_FULL['4-4.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (58, business % AGE_CATEGORIES_FULL['4.5-5-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (59, business % AGE_CATEGORIES_FULL['5-5.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (60, business % AGE_CATEGORIES_FULL['5.5-6-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (61, business % AGE_CATEGORIES_FULL['6-6.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (62, business % AGE_CATEGORIES_FULL['6.5-7-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (63, business % AGE_CATEGORIES_FULL['7-7.5-YEARS'], en['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),
            (64, short_stay % AGE_CATEGORIES_CUT['2M-3YEARS'], en['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (65, short_stay % AGE_CATEGORIES_CUT['3-5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (66, short_stay % AGE_CATEGORIES_CUT['5-7.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),
            (67, care_non_state % AGE_CATEGORIES_CUT['2M-3YEARS'], en['GROUP_TYPE'][GROUP_TYPES['CARE']][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (68, care_non_state % AGE_CATEGORIES_CUT['3-5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['CARE']][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (69, care_non_state % AGE_CATEGORIES_CUT['5-7.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['CARE']][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),
            (70, care_business % AGE_CATEGORIES_CUT['2M-3YEARS'], en['GROUP_TYPE'][GROUP_TYPES['CARE']][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (71, care_business % AGE_CATEGORIES_CUT['3-5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['CARE']][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (72, care_business % AGE_CATEGORIES_CUT['5-7.5-YEARS'], en['GROUP_TYPE'][GROUP_TYPES['CARE']][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),
            (73, inline_enrolled % AGE_CATEGORIES_FULL['2-6-MONTHS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
            (74, inline_enrolled % AGE_CATEGORIES_FULL['0.5-1-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
            (75, inline_enrolled % AGE_CATEGORIES_FULL['1-1.5-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
            (76, inline_enrolled % AGE_CATEGORIES_FULL['1.5-2-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
            (77, inline_enrolled % AGE_CATEGORIES_FULL['2-2.5-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
            (78, inline_enrolled % AGE_CATEGORIES_FULL['2.5-3-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
            (79, inline_enrolled % AGE_CATEGORIES_FULL['3-3.5-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
            (80, inline_enrolled % AGE_CATEGORIES_FULL['3.5-4-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
            (81, inline_enrolled % AGE_CATEGORIES_FULL['4-4.5-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
            (82, inline_enrolled % AGE_CATEGORIES_FULL['4.5-5-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
            (83, inline_enrolled % AGE_CATEGORIES_FULL['5-5.5-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
            (84, inline_enrolled % AGE_CATEGORIES_FULL['5.5-6-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
            (85, inline_enrolled % AGE_CATEGORIES_FULL['6-6.5-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
            (86, inline_enrolled % AGE_CATEGORIES_FULL['6.5-7-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
            (87, inline_enrolled % AGE_CATEGORIES_FULL['7-7.5-YEARS'], en['STATUS'][APPLICATION_STATUSES['IN_LINE_ENROLLED']][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),
        ]
        # В старых отчетах этот показатель не вычислялся
        if 'ALL_CHILDS' in en:
            data.extend([
                (88, all_childs % AGE_CATEGORIES_FULL['2-6-MONTHS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['2-6-MONTHS']]),
                (89, all_childs % AGE_CATEGORIES_FULL['0.5-1-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['0.5-1-YEARS']]),
                (90, all_childs % AGE_CATEGORIES_FULL['1-1.5-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['1-1.5-YEARS']]),
                (91, all_childs % AGE_CATEGORIES_FULL['1.5-2-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['1.5-2-YEARS']]),
                (92, all_childs % AGE_CATEGORIES_FULL['2-2.5-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['2-2.5-YEARS']]),
                (93, all_childs % AGE_CATEGORIES_FULL['2.5-3-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['2.5-3-YEARS']]),
                (94, all_childs % AGE_CATEGORIES_FULL['3-3.5-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['3-3.5-YEARS']]),
                (95, all_childs % AGE_CATEGORIES_FULL['3.5-4-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['3.5-4-YEARS']]),
                (96, all_childs % AGE_CATEGORIES_FULL['4-4.5-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['4-4.5-YEARS']]),
                (97, all_childs % AGE_CATEGORIES_FULL['4.5-5-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['4.5-5-YEARS']]),
                (98, all_childs % AGE_CATEGORIES_FULL['5-5.5-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['5-5.5-YEARS']]),
                (99, all_childs % AGE_CATEGORIES_FULL['5.5-6-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['5.5-6-YEARS']]),
                (100, all_childs % AGE_CATEGORIES_FULL['6-6.5-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['6-6.5-YEARS']]),
                (101, all_childs % AGE_CATEGORIES_FULL['6.5-7-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['6.5-7-YEARS']]),
                (102, all_childs % AGE_CATEGORIES_FULL['7-7.5-YEARS'], en['ALL_CHILDS'][AGE_CATEGORIES_FULL['7-7.5-YEARS']]),
            ])
        if AGE_CATEGORIES_FULL_CURRENT['C2-6-MONTHS'] in en['COMMON']:
            data.extend([
                (103, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C2-6-MONTHS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C2-6-MONTHS']]),
                (104, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C0.5-1-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C0.5-1-YEARS']]),
                (105, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C1-1.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C1-1.5-YEARS']]),
                (106, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C1.5-2-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C1.5-2-YEARS']]),
                (107, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C2-2.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C2-2.5-YEARS']]),
                (108, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C2.5-3-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C2.5-3-YEARS']]),
                (109, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C3-3.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C3-3.5-YEARS']]),
                (110, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C3.5-4-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C3.5-4-YEARS']]),
                (111, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C4-4.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C4-4.5-YEARS']]),
                (112, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C4.5-5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C4.5-5-YEARS']]),
                (113, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C5-5.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C5-5.5-YEARS']]),
                (114, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C5.5-6-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C5.5-6-YEARS']]),
                (115, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C6-6.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C6-6.5-YEARS']]),
                (116, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C6.5-7-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C6.5-7-YEARS']]),
                (117, count_people_current_date % AGE_CATEGORIES_FULL_CURRENT['C7-7.5-YEARS'], en['COMMON'][AGE_CATEGORIES_FULL_CURRENT['C7-7.5-YEARS']]),
            ])
        return data

    def get_capacities_view_data(self):
        """
        Данные отчета по учреждению по свободным местам в формате,
        годном для загрузки в грид
        """
        ca = json.loads(self.capacities)
        common = u'Количество свободных мест на дату сбора отчета в группы в возрасте %s'
        disabled = (u'Количество свободных мест в группах для детей с ограниченными '
                    u'возможностями здоровья в возрасте %s')
        non_state = u'Количество свободных мест в негосударственных ДОО в группы в возрасте %s'
        business = (u'Количество свободных мест у ИП, реализующих программы '
                    u'дошкольного образования, в группы в возрасте %s')
        short_stay = u'Количество свободных мест в группах кратковременного пребывания в возрасте %s'

        data = [
            (0, common % AGE_CATEGORIES_CUT['2M-3YEARS'], ca['COMMON'][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (1, common % AGE_CATEGORIES_CUT['3-5-YEARS'], ca['COMMON'][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (2, common % AGE_CATEGORIES_CUT['5-7.5-YEARS'], ca['COMMON'][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),

            (3, disabled % AGE_CATEGORIES_CUT['2M-3YEARS'], ca['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (4, disabled % AGE_CATEGORIES_CUT['3-5-YEARS'], ca['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (5, disabled % AGE_CATEGORIES_CUT['5-7.5-YEARS'], ca['GROUP_TYPE'][GROUP_TYPES['DISABLED']][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),

            (6, non_state % AGE_CATEGORIES_CUT['2M-3YEARS'], ca['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (7, non_state % AGE_CATEGORIES_CUT['3-5-YEARS'], ca['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (8, non_state % AGE_CATEGORIES_CUT['5-7.5-YEARS'], ca['DOO_TYPE'][DOO_TYPES['NON_STATE']][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),

            (9, business % AGE_CATEGORIES_CUT['2M-3YEARS'], ca['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (10, business % AGE_CATEGORIES_CUT['3-5-YEARS'], ca['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (11, business % AGE_CATEGORIES_CUT['5-7.5-YEARS'], ca['DOO_TYPE'][DOO_TYPES['BUSINESS']][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),

            (12, short_stay % AGE_CATEGORIES_CUT['2M-3YEARS'], ca['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['2M-3YEARS']]),
            (13, short_stay % AGE_CATEGORIES_CUT['3-5-YEARS'], ca['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['3-5-YEARS']]),
            (14, short_stay % AGE_CATEGORIES_CUT['5-7.5-YEARS'], ca['GROUP_TYPE'][GROUP_TYPES['SHORT_STAY']][AGE_CATEGORIES_CUT['5-7.5-YEARS']]),
        ]
        return data


class ScheduleSettings(models.Model):
    """
    Модель настроек celery beat
    """
    PK = 1
    push_login = models.CharField(u'Логин для отправки', max_length=30, null=True)
    push_password = models.CharField(u'Пароль для отправки', max_length=30, null=True)

    time = models.TimeField(verbose_name=u'Время начала', null=True)
    is_active = models.BooleanField(verbose_name=u'Включение автоматического сбора',
                                    default=False)
    resend_count = models.PositiveSmallIntegerField(verbose_name=u'Количество повторных отправок при неудаче',
                                                    default=3)
    zip_xml = models.BooleanField(verbose_name=u'Кодировать данные при отправке в ZIP', default=False)

    def save(self, force_insert=False, force_update=False, using=None):
        self.pk = self.PK
        super(ScheduleSettings, self).save(force_update, force_update, using)

    @staticmethod
    def get_settings():
        ss, created = ScheduleSettings.objects.get_or_create(id=ScheduleSettings.PK,
                                                             defaults={'id': ScheduleSettings.PK})
        return ss


class TaskScheduler(models.Model):
    """
    Планировщик для сбора данных
    """
    periodic_task = models.ForeignKey(PeriodicTask)

    @staticmethod
    def schedule_every(task_name, hour, minute, args='[]', kwargs='{}'):
        """
        schedules a task by name
        """
        ptask_name = "%s_%s" % (task_name, datetime.datetime.now())
        crontab_schedules = CrontabSchedule.objects.filter(hour=hour, minute=minute,
                                                           day_of_week='*', day_of_month='*', month_of_year='*')
        crontab_schedule = (crontab_schedules[0]
                            if crontab_schedules.exists()
                            else CrontabSchedule.objects.create(hour=hour, minute=minute))
        ptask = PeriodicTask.objects.create(name=ptask_name,
                                            task=task_name,
                                            crontab=crontab_schedule,
                                            args=args,
                                            kwargs=kwargs)
        return TaskScheduler.objects.create(periodic_task=ptask)

    def stop(self):
        self.periodic_task.enabled = False
        self.periodic_task.save()

    def start(self):
        self.periodic_task.enabled = True
        self.periodic_task.save()

    def terminate(self):
        self.stop()
        self.delete()
        self.periodic_task.delete()