# coding: utf-8
"""
Модуль функций подсчета показателей.
"""
import datetime

from django.db.models import Q
import settings as gs_settings

from kinder.core.declaration.models import DeclarationUnit, Declaration
from kinder.core.declaration_status.models import DSS
from kinder.core.group.models import Pupil, GroupStatusEnum
from kinder.core.unit.models import UnitKind, Unit

from kinder.core.privilege.models import Privilege
from kinder.core.dict.models import HealthNeed
from kinder.core.alloc.helpers import GroupHelper

from constants import (AGE_CATEGORY_DELTAS, DELIVERY_TYPES, ALL,
                       APPLICATION_STATUSES, GROUP_TYPES,
                       AGE_SUBCATEGORY_MAP, AGE_CATEGORY_MAP, AGE_DELTAS,
                       GOVERMENT, get_report_period, get_last_day_of_academic_year)

# статусы заявлений для запросов
APPROVED_STATUS_CODES = [DSS.ZAGS_CHECKING, DSS.DUL_CONFIRMATING,
                         DSS.PRIV_CONFIRMATING, DSS.MED_CONFIRMATING,
                         DSS.TUTOR_CONFIRMATING, DSS.WANT_CHANGE_DOU,
                         DSS.REGISTERED]
REFUSED_STATUS_CODES = [DSS.REFUSED]
EXCLUDE_STATUSES = [DSS.ACCEPTED, DSS.ARCHIVE]

FEDERAL = 1
MUNICIPAL = 2
REGIONAL = 3
PRIVELEGE_TYPE = {
    FEDERAL: u'Федеральная',
    MUNICIPAL: u'Муниципальная',
    REGIONAL: u'Региональная'
}

def _get_base_queue_for_unit(calc, unit_id, dou_type, ages_const):

    result = []
    if unit_id in calc.queue_cache and dou_type in calc.queue_cache[unit_id]:
        result = calc.queue_cache[unit_id][dou_type][ages_const]

    return result

def count_of_children_in_short_stay(calc, unit_id, ages_const, dou_type=GOVERMENT):
    """
    Количество детей в очереди в группы кратковременного пребывания
    Считаем как заявки с типом work_type = кратковременный (3-5)(id=4)
    @param calc: экземпляр класса расчета
    @param ages_const: Константа границ возрастной категории
    @param unit_id: id учреждения, для которого считается очередь
    @return:
    """
    qs = _get_base_queue_for_unit(calc, unit_id, dou_type, ages_const)
    qs = filter(lambda x: x['work_type__code']=='3-5', qs)
    return len(qs)


def count_of_children_in_queue_base(calc, unit_id, ages_const, dou_type=GOVERMENT):
    """
    Очередь как есть
    @param calc: экземпляр класса расчета
    @param ages_const: Константа границ возрастной категории
    @param unit_id: id учреждения, для которого считается очередь
    """
    qs = _get_base_queue_for_unit(calc, unit_id, dou_type, ages_const)
    return len(qs)


def count_of_children_in_privilege_queue(calc, unit_id, ages_const, type=None, dou_type=GOVERMENT):
    """
    Очередь только по льготникам
    отличается по списку статусов и наличию лгот
    @param calc: экземпляр класса расчета
    @param ages_const: Константа границ возрастной категории
    @param unit_id: id учреждения, для которого считается очередь
    @return:
    """
    qs = _get_base_queue_for_unit(calc, unit_id, dou_type, ages_const)
    qs = filter(lambda x: x['best_privilege__id']!=None, qs)
    qs = filter(lambda x: x['status__code']==DSS.REGISTERED, qs)
    qs = filter(lambda x: x['desired_date']==None or x['desired_date']<=get_last_day_of_academic_year(), qs)
    if type:
        if type == REGIONAL:
            privilege_filter = Q(type=REGIONAL) | Q(type=MUNICIPAL)
        else:
            privilege_filter = Q(type=type)
        qs_pr = Privilege.objects.filter(privilege_filter).values_list('id', flat=True)
        qs = filter(lambda x: x['best_privilege__id'] in qs_pr, qs)
    return len(qs)


def children_without_place_count(calc, unit_id, ages_const, dou_type=GOVERMENT):
    """
    Подсчет количества детей, не обеспеченных местом в ДОУ
    @param calc: экземпляр класса расчета
    @param ages_const: Константа границ возрастной категории
    @param unit_id: id учреждения, для которого считается очередь
    """
    base_qs = _get_base_queue_for_unit(calc, unit_id, dou_type, ages_const)
    base_qs = filter(lambda x: x['desired_date']==None or x['desired_date'] <= get_last_day_of_academic_year(), base_qs)
    return len(base_qs)


def children_with_health_need_count(calc, unit_id, ages_const, comp=0, dou_type=GOVERMENT):
    """
    Подсчет количества детей  в очереди, имеющих потребности по здоровью
    @param calc: экземпляр класса расчета
    @param ages_const: Константа границ возрастной категории
    @param unit_id: id учреждения, для которого считается очередь
    @param comp: 0 все группы
    comp 1 компенсирующие группы
    comp 2 оздоровительные группы
    """
    qs = _get_base_queue_for_unit(calc, unit_id, dou_type, ages_const)
    if comp == 0:
        qs_hn = HealthNeed.objects.exclude(name=u'Нет').values_list('id', flat=True)
    elif comp == 1:
        #id потребностей из документа расчета показателей
        qs_hn = range(1, 10) + [12, 13]
    elif comp == 2:
        qs_hn = [14, 15, 16]
    qs = filter(lambda x: x['children__health_need_id'] in qs_hn, qs)
    return len(qs)


def postponed_queue_children_count(calc, unit_id, ages_const, dou_type=GOVERMENT):
    """
    Количетство детей в отложенной очереди
    Заявки с желаемой датой зачисления больше 10.09.текущий_учебный_год
    + если комплектование прошло (дата окончания < текущей) то те дети у кого дата
    желаемого зачисления пустая либо меньше 31.12.текущий_год
    @param calc: экземпляр класса расчета
    @param ages_const: Константа границ возрастной категории
    @param unit_id: id учреждения, для которого считается очередь
    """
    base_qs = _get_base_queue_for_unit(calc, unit_id, dou_type, ages_const)

    base_qs = filter(lambda x: x['desired_date'] and x['desired_date'] > get_last_day_of_academic_year(), base_qs)
    count = len(base_qs)

    return count

#----------------------------------------------
# расчеты по количеству заявлений
#----------------------------------------------
def _get_applications_count(unit, dou_type=GOVERMENT, **query_params):
    """
    Подсчет заявлений
    """

    def _calc_without_consider_priority(qs, units):

        count = (DeclarationUnit.objects.filter(declaration__in=qs,
                                                unit__id__in=units)
                                        .filter(filter_by_dou_type)
                                        .distinct('declaration')).count()
        return count

    def _calc_with_consider_priority(qs, unit):

        count = 0

        if ((not unit.dou_type and dou_type != GOVERMENT) or (unit.dou_type and unit.dou_type.code != dou_type)):
            return count

        # Сознательно загружаю в память, чтобы не плодить сотни запросов.
        declaration_units = list(DeclarationUnit.objects.filter(declaration__in=qs, unit__kind__id=UnitKind.DOU)
                                                        .values('declaration', 'ord', 'unit__id'))
        for q in qs:
            this_declaration_units = filter(lambda x: x['declaration']==q.id, declaration_units)
            this_declaration_units = sorted(this_declaration_units, key=lambda x: x['ord'])
            if this_declaration_units and this_declaration_units[0]['unit__id'] == unit.id:
                count = count + 1

        return count

    query = Declaration.objects.filter(**query_params).select_related('children')

    # Фильтрация по отчетному периоду.
    begin_report_period, end_report_period = get_report_period()
    query = query.filter(Q(date__gte=begin_report_period) & Q(date__lte=end_report_period))

    units = unit.get_descendants(include_self=True)
    filter_by_dou_type = Q(unit__dou_type__code=dou_type)
    if dou_type == GOVERMENT: filter_by_dou_type |= Q(unit__dou_type=None)
    query = query.filter(mo=unit.get_mo())
    if unit.kind.id == UnitKind.MO:
        count = _calc_without_consider_priority(query, units)
        #(query.filter(mo__id__in=units.filter(kind=UnitKind.MO)).count())
    else:
        if gs_settings.NO_CONSIDER_PRIORITY:
            count = _calc_without_consider_priority(query, units)
        else:
            count = _calc_with_consider_priority(query, unit)

    return count


def get_applications_count_by_age(unit, age_range, dou_type=GOVERMENT):
    """количество заявлений по возрастам"""
    down_border, up_border = AGE_CATEGORY_DELTAS[age_range]
    return _get_applications_count(unit,
                                   dou_type=dou_type,
                                   **{'children__date_of_birth__gte': down_border,
                                      'children__date_of_birth__lt': up_border})

def get_applications_count_by_delivery(unit, delivery):
    """количество заявлений по типу подачи"""
    down_border, up_border = AGE_DELTAS['7.5_year'], AGE_DELTAS['2_months']
    return _get_applications_count(unit,
                                   dou_type=GOVERMENT,
                                   **{'portal': int(delivery == DELIVERY_TYPES['PORTAL']),
                                      'children__date_of_birth__gte': down_border,
                                     'children__date_of_birth__lt': up_border})

def get_applications_count_by_group_type(unit, group_type, age_range):
    """количество заявлений по типу группы"""
    query_params = {}
    if group_type == GROUP_TYPES['SHORT_STAY']:
        query_params['work_type__code'] = '3-5'
    down_border, up_border = AGE_CATEGORY_DELTAS[age_range]
    query_params['children__date_of_birth__gte'] = down_border
    query_params['children__date_of_birth__lt'] = up_border
    return _get_applications_count(unit, dou_type=GOVERMENT, **query_params)


#: количество отказов
def get_denied_applications_count(unit):
    down_border, up_border = AGE_DELTAS['7.5_year'], AGE_DELTAS['2_months']
    return _get_applications_count(unit,
                                   dou_type=GOVERMENT,
                                   **{'status__code__in': ['didnt_come', 'refused'],
                                      'children__date_of_birth__gte': down_border,
                                      'children__date_of_birth__lt': up_border})

#----------------------------------------------
# расчеты по количеству зачисленных детей
#----------------------------------------------
def _get_enrolled_count(unit, dou_type=GOVERMENT, **query_params):
    """Подсчет зачисленных детей"""
    filter_by_dou_type = Q(dou_type__code=dou_type)
    if dou_type == GOVERMENT: filter_by_dou_type |= Q(dou_type=None)
    return (Pupil.objects
            .select_related('children', 'grup')
            .filter(grup__status=GroupStatusEnum.FACT,
                    grup__unit__in=unit.get_descendants(include_self=True)
                    .filter(kind=UnitKind.DOU).filter(filter_by_dou_type),
                    **query_params)
            .count())


def get_enrolled_want_change_doo(unit, age_range=ALL):
    """количество детей зачисленных и желающих сменить доо"""
    filter_by_dou_type = Q(dou_type__code=GOVERMENT) | Q(dou_type=None)
    childrens = (Pupil.objects.filter(grup__status=GroupStatusEnum.FACT,
                                      grup__unit__in=unit.get_descendants(include_self=True).filter(kind=UnitKind.DOU).
                                                         filter(filter_by_dou_type)))

    down_border, up_border = AGE_CATEGORY_DELTAS[age_range]
    childrens = childrens.filter(Q(children__date_of_birth__gte=down_border) & Q(children__date_of_birth__lt=up_border))

    childrens = childrens.values('children__id')

    declarations = Declaration.objects.filter(status__code=DSS.WANT_CHANGE_DOU, children__in=childrens)
    childrens_want_change_dou = declarations.values('children').distinct()

    return childrens_want_change_dou.count()

def get_enrolled_count_by_age(unit, age_range, dou_type=GOVERMENT):
    """количество зачисленных детей по возрастам"""
    down_border, up_border = AGE_CATEGORY_DELTAS[age_range]
    return _get_enrolled_count(unit, dou_type, **{'children__date_of_birth__gte': down_border,
                                                  'children__date_of_birth__lt': up_border})



def get_enrolled_health_count_by_age(unit, age_range):
    """количество зачисленных и нуждающихся детей по возрастам"""
    down_border, up_border = AGE_CATEGORY_DELTAS[age_range]
    return _get_enrolled_count(unit, **{'grup__health_need__isnull': False,
                                        'children__date_of_birth__gte': down_border,
                                        'children__date_of_birth__lt': up_border})


def get_enrolled_count_by_group_type(unit, group_type, age_range=ALL):
    """Данные по зачисленным детям по типам групп"""
    query_params = {}
    if group_type == GROUP_TYPES['FAMILY']:
        query_params['grup__is_family'] = True
    elif group_type == GROUP_TYPES['DISABLED']:
        query_params['grup__type__code__in'] = ['compensative', 'health']
    elif group_type == GROUP_TYPES['CORRECT']:
        query_params['grup__type__code'] = 'compensative'
    elif group_type == GROUP_TYPES['HEALTH']:
        query_params['grup__type__code'] = 'health'
    elif group_type == GROUP_TYPES['SHORT_STAY']:
        query_params['grup__work_type__code'] = '3-5'
    elif group_type == GROUP_TYPES['CARE']:
        # query_params['grup__type__code'] = False
        return 0

    down_border, up_border = AGE_CATEGORY_DELTAS[age_range]
    query_params['children__date_of_birth__gte'] = down_border
    query_params['children__date_of_birth__lt'] = up_border
    return _get_enrolled_count(unit, **query_params)


def get_enrolled_count_by_status(unit, status, age_range=ALL):
    """Данные по зачисленным детям по статусам"""
    query_params = {}
    if status == APPLICATION_STATUSES['WANT_CHANGE_DOO']:
        pass
    down_border, up_border = AGE_CATEGORY_DELTAS[age_range]
    query_params['children__date_of_birth__gte'] = down_border
    query_params['children__date_of_birth__lt'] = up_border
    return _get_enrolled_count(unit, **query_params)


#----------------------------------------------
# расчеты по количеству свободных мест
#----------------------------------------------
class GisdoGroupHelper(GroupHelper):
    """
    Отличается от родителя тем, что добавлены дополнительные фильтры
    """

    def getQuery(self, reporting=False):

        q, tmp_dict = super(GisdoGroupHelper, self).getQuery(reporting)

        # Группы кратковременного пребывания
        short_stay = getattr(self.context, 'short_stay', False)
        if short_stay:
            q = q.filter(work_type__code = '3-5')

        # Потребность по здоровью
        health_need_filter = getattr(self.context, 'health_need_filter', False)
        if health_need_filter:
            # (#85387) Считать, как количество всех детей зачисленных в группы типа "Оздоровительные"
            # или "Компенсирующие" без учета наличия или отсутствия потребности по здоровью.
            q = q.filter(type__code__in=['health', 'compensative'])

        dou_type = getattr(self.context, 'dou_type', GOVERMENT)
        filter_by_dou_type = Q(unit__dou_type__code=dou_type)
        if dou_type == GOVERMENT: filter_by_dou_type |= Q(unit__dou_type=None)
        q = q.filter(filter_by_dou_type)

        return q, tmp_dict

    @classmethod
    def get_count(cls, context, age_category):

        total = 0
        for group in cls(context).getList():

            # Если у группы есть возрастная подкатегория, то соотношение проводится по ней
            if group.sub_age_cat:
                if group.sub_age_cat.code in AGE_SUBCATEGORY_MAP[age_category]:
                    total += group.cntFree
            # в противном случае по возрастной категории, которая обязательна.
            else:
                if group.age_cat.code in AGE_CATEGORY_MAP[age_category]:
                    total += group.cntFree

        return total

def get_capacities_count(unit, age_category=None, dou_type=GOVERMENT):
    """Подсчет показателей по свободным местам"""
    class Context(object):
        kind = 1 # магическое число указывает на то, что группа фактическая.
                 # использую потому, что это значение строго вшито в GroupHelper
        def __init__(self, unit_id):

            self.group_unit = unit_id
            self.dou_type = dou_type

    return GisdoGroupHelper.get_count(Context(unit.id), age_category)

def get_capacities_count_by_group_type(unit, group_type, age_category):
    """Подсчет показателей по свободным местам по типам групп"""
    class Context(object):
        kind = 1 # магическое число указывает на то, что группа фактическая
        def __init__(self, unit_id, short_stay=False, health_need_filter=False):

            self.group_unit = unit_id
            self.short_stay = short_stay
            self.health_need_filter = health_need_filter

    short_stay = health_need_filter = False
    if group_type == GROUP_TYPES['DISABLED']:
        health_need_filter = True
    if group_type == GROUP_TYPES['SHORT_STAY']:
        short_stay = True

    return GisdoGroupHelper.get_count(Context(unit.id, short_stay=short_stay, health_need_filter=health_need_filter),
                                                    age_category=age_category)

def get_capacities_count_by_doo_type(unit, doo_type, age_category):
    """Подсчет показателей по свободным местам по типам ДОО"""
    return 0